/******************************************************************************
* Project Name		: ADC and UART (a CE95277 alapjn)
* File Name 		: main.c
* Version   		: **
* Device Used		: CY8C5888LTI-LP097
* Software Used		: PSoC Creator 4.1
* Related Hardware	: CY8CKIT-059 PSoC 5 LP Prototyping Kit 
* 
* Lers:
* Ez a program a "CE95277 - Delta Sigma ADC in Single Ended 
* Mode with PSoC3/PSoC 5LP" gyri mintaplda talaktott vltozata. 
* A mdosts sorn a felbontst 20 bitesre nveltk (ez magval vonta a 
* vltoz tpusok s a hasznlt API fggvnyek paramtereinek 32 bitesre nvelst.
* Megvltoztattuk tovbb a kirats formtumt is.
*
* Lbkioszts:
*  P0[0] - analg bemenet (0 V - +6 V kztti jel)
*  P12[6] - UART Rx bemenet
*  P12[7] - UART Tx kimenet
*******************************************************************************/

#include <project.h>
#include "stdio.h"

/* Project Defines */
#define FALSE  0
#define TRUE   1
#define TRANSMIT_BUFFER_SIZE  64


/*******************************************************************************
* Fprogram
********************************************************************************
*
*  main() az albbi funkcikat ltja el:
*  1: Elindtja az ADC s UART alkatrszeket
*  2: Ellenrzi az ADC konverzi vgt.  Eltrolja a legutols konverzi vgt,
*     ha vge van a konverzinak.
*  3: Ellenrzi, hogy rkezett-e valami az UART kapcsolaton
*     Ha 'C' vagy 'c' rkezett: kirja a legutbbi eredmnyt az UART-on
*     Ha 'S' vagy 's' rkezett: folyamatosan kldi a mrt adatokat
*     Ha 'X' vagy 'x' rkezett: lelltja a folyamatos adatkldst.
*     Ha 'E' vagy 'e' rkezett: egy fut sorszmot r ki emullt mrsi adatknt.
*
*******************************************************************************/
int main()
{
    /* Variable to store ADC result */
    uint32 result, milliVolts, microVolts;
    /* Variable to store UART received character */
    uint8 Ch;
    /* Variable used to send emulated data */
    uint8 EmulatedData;
    /* Flags used to store transmit data commands */
    uint8 ContinuouslySendData;
    uint8 SendSingleByte;
    uint8 SendEmulatedData;
    /* Transmit Buffer */
    char TransmitBuffer[TRANSMIT_BUFFER_SIZE];
    
    /* Start the components */
    ADC_DelSig_1_Start();
    UART_1_Start();
    
    /* Initialize Variables */
    ContinuouslySendData = FALSE;
    SendSingleByte = FALSE;
    SendEmulatedData = FALSE;
    EmulatedData = 0;
    
    /* Start the ADC conversion */
    ADC_DelSig_1_StartConvert();
    
    /* Send message to verify COM port is connected properly */
    UART_1_PutString("COM Port Open");
    
    for(;;)
    {        
        /* Non-blocking call to get the latest data recieved  */
        Ch = UART_1_GetChar();
        
        /* Set flags based on UART command */
        switch(Ch)
        {
            case 0:
                /* No new data was recieved */
                break;
            case 'C':
            case 'c':
                SendSingleByte = TRUE;
                break;
            case 'S':
            case 's':
                ContinuouslySendData = TRUE;
                break;
            case 'X':
            case 'x':
                ContinuouslySendData = FALSE;
                break;
            case 'E':
            case 'e':
                SendEmulatedData = TRUE;
                break;
            default:
                /* Place error handling code here */
                break;    
        }
        
        /* Check to see if an ADC conversion has completed */
        if(ADC_DelSig_1_IsEndConversion(ADC_DelSig_1_RETURN_STATUS))
        {
            /* Use the GetResult16 API to get an 8 bit unsigned result in
             * single ended mode.  The API CountsTo_mVolts is then used
             * to convert the ADC counts into mV before transmitting via
             * the UART.  See the datasheet API description for more
             * details */
            result = ADC_DelSig_1_GetResult32();
            microVolts = ADC_DelSig_1_CountsTo_uVolts(result);
            milliVolts = ADC_DelSig_1_CountsTo_mVolts(result);            
            /* Send data based on last UART command */
            if(SendSingleByte || ContinuouslySendData)
            {
                /* Format ADC result for transmition */
                sprintf(TransmitBuffer, "Sample: %lu %lu uV %lu mV\r\n", result, microVolts, milliVolts);
                /* Send out the data */
                UART_1_PutString(TransmitBuffer);              
                /* Reset the send once flag */
                SendSingleByte = FALSE;
            }
            else if(SendEmulatedData)
            {
                /* Format ADC result for transmition */
                sprintf(TransmitBuffer, "Emulated Data: %x \r\n", EmulatedData);
                /* Send out the data */
                UART_1_PutString(TransmitBuffer);
                EmulatedData++;
                /* Reset the send once flag */
                SendEmulatedData = FALSE;   
            }
        }
    }
}


/* [] END OF FILE */
